@@ -35,20 +35,14 @@
 *
 *****/
 
-#include <stdio.h>
-
-#include <map>
 
 #include <qtextview.h>
 #include <qpushbutton.h>
-#include <qsizepolicy.h>
-#include <qpixmap.h>
 #include <qlabel.h>
 #include <qprogressbar.h>
 
 #include "toabout.h"
 #include "toconf.h"
-#include "totool.h"
 
 #include "toabout.moc"
 #include "toaboutui.moc"
@@ -82,6 +76,18 @@ static const char *AboutText = "<IMG SRC=largelogo.xpm><BR>\n"
                                "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
                                "GNU General Public License for more details."
                                "<HR BREAK=ALL>\n"
+                               "Development team (in alphabetical order):<P>\n"
+                               "<UL>\n"
+                               "<LI><B>Alexey Danilchenko</B>\n"
+                               "<LI><B>Henrik Johnson</B>\n"
+                               "<LI><B>Ivan Brezina</B>\n"
+                               "<LI><B>Mike Johnson</B>\n"
+                               "<LI><B>Nathan Neulinger</B>\n"
+                               "<LI><B>Oliver Jehle</B>\n"
+                               "<LI><B>Raj Thukral</B>\n"
+                               "<LI><B>Thomas Porschberg</B>\n"
+                               "<LI><B>Volker Gtz</B>\n"
+                               "</UL>\n"
                                "Contributors (In alphabetical order):<P>\n"
                                "<UL>\n"
                                "<LI><B>Alexander (Leo) Bergolth</B> - Access to Oracle 7 database.\n"
@@ -109,7 +115,9 @@ static const char *AboutText = "<IMG SRC=largelogo.xpm><BR>\n"
                                "<B>Mihai Ibanescu</B>,\n"
                                "<B>Bo Johansson</B>,\n"
                                "<B>Olof Jnsson</B>,\n"
+			       "<B>Michael Kaes</B>,\n"
                                "<B>Norbert Kiesel</B>,\n"
+			       "<B>Pawe=B3 Kucharczyk</B>,\n"
                                "<B>Jacob Lauemølle</B>,\n"
                                "<B>Laramie Leavitt</B>,\n"
                                "<B>Paolo Magnoli</B>,\n"
@@ -117,6 +125,7 @@ static const char *AboutText = "<IMG SRC=largelogo.xpm><BR>\n"
                                "<B>Peter Nyborg</B>,\n"
                                "<B>Frank Pavageau</B>,\n"
                                "<B>Andreas Piesk</B>,\n"
+			       "<B>Gerard H. Pille</B>,\n"
                                "<B>Thomas Porschberg</B>,\n"
                                "<B>Jan Pruner</B>,\n"
                                "<B>Jonas Rathert</B>,\n"
@@ -124,12 +133,12 @@ static const char *AboutText = "<IMG SRC=largelogo.xpm><BR>\n"
                                "<B>Erik Selberg</B>,\n"
                                "<B>Dennis Selsky</B>,\n"
                                "<B>Roman Stepanov</B>,\n"
+			       "<B>Petr Vanek</B>,\n"
                                "<B>Daniel Vrit</B>,\n"
                                "<B>Matthias Wolle</B>,\n"
                                "<B>Joachim Zetzsche</B>,\n"
                                "<B>Massimiliano Ziccardi</B>,\n"
-                               "<B>Raj Thukral</B>,\n"
-                               "<B>Mike Johnson</B>...\n";
+                               "<B>Raj Thukral</B>...\n";
 #  endif
 #endif
 
