@@ -41,6 +41,7 @@
 #include "todebug.h"
 #include "todebugtext.h"
 #include "tosql.h"
+#include "todebugtext.moc"
 
 #include <qapplication.h>
 #include <qpainter.h>
@@ -177,9 +178,6 @@ void toBreakpointItem::clearBreakpoint()
 
 #define DEBUG_INDENT 10
 
-static QPixmap *toBreakpointPixmap;
-static QPixmap *toDisBreakpointPixmap;
-
 static toSQL SQLReadSource("toDebug:ReadSource",
                            "SELECT Text FROM SYS.All_Source\n"
                            " WHERE OWNER = :f1<char[101]>\n"
@@ -228,7 +226,7 @@ bool toDebugText::readData(toConnection &conn, QListView *Stack)
         while (!lines.eof())
             str += lines.readValue();
         setText(str);
-        setEdited(false);
+        setModified(false);
         setCurrent( -1);
 
         if (str.isEmpty())
@@ -265,17 +263,17 @@ toDebugText::toDebugText(QListView *breakpoints,
         Debugger(debugger),
         Breakpoints(breakpoints)
 {
-    setLeftIgnore(DEBUG_INDENT);
-    setHMargin(DEBUG_INDENT + hMargin());
-    setMouseTracking(true);
-    QRect view = viewRect();
-    LastX = DEBUG_INDENT + view.left();
+    //setLeftIgnore(DEBUG_INDENT);
+    setMarginWidth(0, 25);
+    setMarginWidth(1, 10);
+    setMarginSensitivity(0,true);
+    setMarginSensitivity(1,true);
     CurrentItem = FirstItem = NULL;
     NoBreakpoints = false;
-    if (!toBreakpointPixmap)
-        toBreakpointPixmap = new QPixmap(const_cast<const char**>(breakpoint_xpm));
-    if (!toDisBreakpointPixmap)
-        toDisBreakpointPixmap = new QPixmap(const_cast<const char**>(disbreakpoint_xpm));
+    connect(this,SIGNAL(marginClicked(int, int, Qt::ButtonState)),this, SLOT(toggleBreakpoint(int, int, Qt::ButtonState)));
+    breakMarker=markerDefine(new QPixmap(const_cast<const char**>(breakpoint_xpm)));
+    disabledBreakMarker=markerDefine(new QPixmap(const_cast<const char**>(disbreakpoint_xpm)));
+    setMarginMarkerMask(1,2^breakMarker|2^disabledBreakMarker);
 }
 
 bool toDebugText::checkItem(toBreakpointItem *item)
@@ -340,53 +338,9 @@ bool toDebugText::hasBreakpoint(int row) // This has to leave CurrentItem on the
     return false;
 }
 
-void toDebugText::paintCell(QPainter *painter, int row, int col)
-{
-    toHighlightedText::paintCell(painter, row, col);
-    if (col == 0)
-    {
-        QPalette cp = qApp->palette();
-        painter->fillRect(0, 0, DEBUG_INDENT - 2, cellHeight(), cp.active().background());
-        painter->fillRect(DEBUG_INDENT - 2, 0, 1, cellHeight(), cp.active().midlight());
-        painter->fillRect(DEBUG_INDENT - 1, 0, 1, cellHeight(), cp.active().dark());
-
-        if (hasBreakpoint(row))
-        {
-            int h = std::max((cellHeight() - toBreakpointPixmap->height()) / 2, 0);
-            if (CurrentItem->text(4) == "DISABLED")
-                painter->drawPixmap(0, h, *toDisBreakpointPixmap);
-            else
-                painter->drawPixmap(0, h, *toBreakpointPixmap);
-        }
-    }
-}
-
-void toDebugText::paintEvent(QPaintEvent *pe)
-{
-    toHighlightedText::paintEvent(pe);
-    int fromY = 0;
-    if (numRows() == 0 || rowYPos(numRows() - 1, &fromY))
-    {
-        if (numRows())
-            fromY += cellHeight();
-        QRect view = viewRect();
-        if (fromY + view.top() < view.height())
-        {
-            QPainter painter(this);
-            QPalette cp = qApp->palette();
-            if (xOffset() < DEBUG_INDENT - 3)
-                painter.fillRect(view.left(), fromY, DEBUG_INDENT - 2 - xOffset(), view.bottom() - fromY, cp.active().background());
-            if (xOffset() < DEBUG_INDENT - 2)
-                painter.fillRect(view.left() + DEBUG_INDENT - 2 - xOffset(), fromY, 1, view.bottom() - fromY, cp.active().midlight());
-            if (xOffset() < DEBUG_INDENT - 1)
-                painter.fillRect(view.left() + DEBUG_INDENT - 1 - xOffset(), fromY, 1, view.bottom() - fromY, cp.active().dark());
-        }
-    }
-}
-
 void toDebugText::mouseMoveEvent(QMouseEvent *me)
 {
-    QRect view = viewRect();
+    QRect view = childrenRect ();
     if (me->x() > DEBUG_INDENT + view.left())
     {
         if (LastX <= DEBUG_INDENT + view.left())
@@ -421,15 +375,22 @@ void toDebugText::toggleBreakpoint(int row, bool enable)
             {
                 if (enable)
                 {
-                    if (CurrentItem->text(4) == qApp->translate("toDebug", "DISABLED"))
+                    if (CurrentItem->text(4) == qApp->translate("toDebug", "DISABLED")){
                         CurrentItem->setText(4, qApp->translate("toDebug", "DEFERED"));
-                    else
+                        markerDelete(row,disabledBreakMarker);
+                        markerAdd(row,breakMarker);
+                    }else{
                         CurrentItem->clearBreakpoint();
+                        markerDelete(row,breakMarker);
+                        markerAdd(row,disabledBreakMarker);
+                    }
                 }
                 else
                 {
                     CurrentItem->clearBreakpoint();
                     delete CurrentItem;
+                    markerDelete(row,breakMarker);
+                    markerDelete(row,disabledBreakMarker);
                     if (FirstItem == CurrentItem)
                     {
                         NoBreakpoints = false;
@@ -444,6 +405,7 @@ void toDebugText::toggleBreakpoint(int row, bool enable)
         }
         else if (!enable)
         {
+            markerAdd(row,breakMarker);
             if (CurrentItem && CurrentItem->line() > row)
                 new toBreakpointItem(Breakpoints, NULL,
                                      Schema, Type, Object, row);
@@ -453,21 +415,17 @@ void toDebugText::toggleBreakpoint(int row, bool enable)
             FirstItem = CurrentItem = NULL;
             NoBreakpoints = false;
         }
-        updateCell(row, 0, false);
+        //updateCell(row, 0, false);
     }
 }
 
-void toDebugText::mouseDoubleClickEvent(QMouseEvent *me)
-{
-    if (me->x() + xOffset() > DEBUG_INDENT)
-        toHighlightedText::mouseDoubleClickEvent(me);
-    else
-    {
-        int row = findRow(me->y());
-        toggleBreakpoint(row);
-    }
+
+void toDebugText::toggleBreakpoint(int margin, int line, Qt::ButtonState   state){
+  if(margin<=1) 
+    toggleBreakpoint(line);
 }
 
+
 void toDebugText::exportData(std::map<QCString, QString> &data, const QCString &prefix)
 {
     toHighlightedText::exportData(data, prefix);
