@@ -44,16 +44,6 @@
 #include "tosearchreplace.h"
 #include "totool.h"
 
-#if QT_VERSION >= 0x030000
-#include "qtlegacy/qtmultilineedit.cpp"
-#include "qtlegacy/qttableview.cpp"
-#include "qtlegacy/qtmultilineedit.moc"
-#include "qtlegacy/qttableview.moc"
-#include "tomarkedtext.3.moc"
-#else
-#include "tomarkedtext.2.moc"
-#endif
-
 #ifdef TO_HAS_KPRINT
 #include <kprinter.h>
 #endif
@@ -65,19 +55,26 @@
 #include <qpainter.h>
 #include <qpalette.h>
 #include <qprinter.h>
+#include <qclipboard.h>
 
 #include "tomarkedtext.moc"
 
+#define ACCEL_KEY(k) "\t" + QString("Ctrl+" #k)
+
+
+// static value for default tab width
+int toMarkedText::defTabWidth = 8;
+
+
 toMarkedText::toMarkedText(QWidget *parent, const char *name)
-        : toMultiLineEdit(parent, name), toEditWidget()
+        : QextScintilla(parent, name), toEditWidget()
 {
     setEdit();
     Search = false;
     setFont(toStringToFont(toTool::globalConfig(CONF_TEXT, "")));
 
-    connect(this, SIGNAL(redoAvailable(bool)), this, SLOT(setRedoAvailable(bool)));
-    connect(this, SIGNAL(undoAvailable(bool)), this, SLOT(setUndoAvailable(bool)));
-    connect(this, SIGNAL(copyAvailable(bool)), this, SLOT(setCopyAvailable(bool)));
+    connect(this, SIGNAL(textChanged()), this, SLOT(setTextChanged()));
+    connect(this,SIGNAL(copyAvailable(bool)),this,SLOT(setCopyAvailable(bool)));
 
     QPalette pal = palette();
     pal.setColor(QColorGroup::Base,
@@ -87,22 +84,29 @@ toMarkedText::toMarkedText(QWidget *parent, const char *name)
     setPalette(pal);
 
     CursorTimerID = -1;
+    
+    // sets default tab width
+    setTabWidth(defaultTabWidth());
 }
 
+void toMarkedText::setCopyAvailable(bool yes){
+  setEdit();
+} 
+
 void toMarkedText::setEdit(void)
 {
     if (isReadOnly())
     {
         toEditWidget::setEdit(false, true, true,
                               false, false,
-                              false, hasMarkedText(), false,
+                              false, hasSelectedText(), false,
                               true, true, false);
     }
     else
     {
         toEditWidget::setEdit(true, true, true,
                               undoEnabled(), redoEnabled(),
-                              hasMarkedText(), hasMarkedText(), true,
+                              hasSelectedText(), hasSelectedText(), true,
                               true, true, false);
     }
     toMain::editEnable(this);
@@ -114,7 +118,7 @@ void toMarkedText::focusInEvent (QFocusEvent *e)
     int curline, curcol;
     getCursorPosition (&curline, &curcol);
     toMainWidget()->setCoordinates(curline + 1, curcol + 1);
-    toMultiLineEdit::focusInEvent(e);
+    QextScintilla::focusInEvent(e);
     if (CursorTimerID < 0)
         CursorTimerID = startTimer(500);
 }
@@ -128,7 +132,7 @@ void toMarkedText::timerEvent(QTimerEvent *e)
         toMainWidget()->setCoordinates(curline + 1, curcol + 1);
     }
     else
-        toMultiLineEdit::timerEvent(e);
+        QextScintilla::timerEvent(e);
 }
 
 void toMarkedText::focusOutEvent (QFocusEvent *e)
@@ -144,20 +148,15 @@ void toMarkedText::focusOutEvent (QFocusEvent *e)
         killTimer(CursorTimerID);
         CursorTimerID = -1;
     }
-    toMultiLineEdit::focusOutEvent(e);
+    QextScintilla::focusOutEvent(e);
 }
 
 void toMarkedText::dropEvent(QDropEvent *e)
 {
-    toMultiLineEdit::dropEvent(e);
+    QextScintilla::dropEvent(e);
     setFocus();
 }
 
-void toMarkedText::paintEvent(QPaintEvent *pe)
-{
-    toMultiLineEdit::paintEvent(pe);
-}
-
 void toMarkedText::editPrint(void)
 {
     TOPrinter printer;
@@ -175,7 +174,7 @@ void toMarkedText::editPrint(void)
                 (line = printPage(&printer, &painter, line, offset, page++, false)))
             painter.resetXForm();
         while ((line = printPage(&printer, &painter, line, offset, page++)) &&
-                line < numLines() &&
+                line < lines() &&
                 (printer.toPage() == 0 || page <= printer.toPage()))
         {
             printer.newPage();
@@ -229,20 +228,20 @@ int toMarkedText::printPage(TOPrinter *printer, QPainter *painter, int line, int
             painter->drawText(0, pos,
                               metrics.width(), metrics.height(),
                               AlignLeft | AlignTop | ExpandTabs | WordBreak,
-                              textLine(line), -1, &bound);
+                              text(line), -1, &bound);
         }
         else
             bound = painter->boundingRect(0, pos,
                                           metrics.width(), metrics.height(),
                                           AlignLeft | AlignTop | ExpandTabs | WordBreak,
-                                          textLine(line));
+                                          text(line));
         int cheight = bound.height() ? bound.height() : height;
         totalHeight -= cheight;
         pos += cheight;
         if (totalHeight >= 0)
             line++;
     }
-    while (totalHeight > 0 && line < numLines());
+    while (totalHeight > 0 && line < lines());
     painter->setClipping(false);
     offset = totalHeight;
     painter->setFont(defFont);
@@ -254,14 +253,14 @@ void toMarkedText::openFilename(const QString &file)
     QCString data = toReadFile(file);
     setText(QString::fromLocal8Bit(data));
     setFilename(file);
-    setEdited(false);
+    setModified(false);
     toMainWidget()->addRecentFile(file);
     toStatusMessage(tr("File opened successfully"), false, false);
 }
 
 bool toMarkedText::editOpen(QString suggestedFile)
 {
-    if (edited())
+    if (isModified())
     {
         int ret = TOMessageBox::information(this,
                                             tr("Save changes?"),
@@ -307,7 +306,7 @@ bool toMarkedText::editSave(bool askfile)
             return false;
         toMainWidget()->addRecentFile(fn);
         setFilename(fn);
-        setEdited(false);
+        setModified(false);
         return true;
     }
     return false;
@@ -315,14 +314,29 @@ bool toMarkedText::editSave(bool askfile)
 
 void toMarkedText::newLine(void)
 {
-    toMultiLineEdit::newLine();
+    // new line
+    switch (eolMode()) {
+        case EolWindows:
+            insert ("\n\r");
+            break;
+		
+		case EolMac:
+           insert ("\n");
+           break;
+
+        default:
+            // Unix is default one
+            insert ("\r");
+            break;
+    }
+    
     if (!toTool::globalConfig(CONF_AUTO_INDENT, "Yes").isEmpty())
     {
         int curline, curcol;
         getCursorPosition (&curline, &curcol);
         if (curline > 0)
         {
-            QString str = textLine(curline - 1);
+            QString str = text(curline - 1);
             QString ind;
             for (unsigned int i = 0;i < str.length() && str.at(i).isSpace();i++)
                 ind += str.at(i);
@@ -334,8 +348,8 @@ void toMarkedText::newLine(void)
 
 void toMarkedText::searchFound(int line, int col)
 {
-    setCursorPosition(line, col + SearchString.length(), false);
-    setCursorPosition(line, col, true);
+    setSelection (line, col + SearchString.length(), line, col);
+    ensureCursorVisible();
     toStatusMessage(tr("Incremental search") + QString::fromLatin1(":") + SearchString, false, false);
 }
 
@@ -351,19 +365,19 @@ void toMarkedText::incrementalSearch(bool forward, bool next)
             curline = 0;
             curcol = 0;
             next = false;
-            line = textLine(curline);
+            line = text(curline);
         }
         else
         {
-            curline = numLines() - 1;
-            line = textLine(curline);
+            curline = lines() - 1;
+            line = text(curline);
             curcol = line.length();
             next = false;
         }
         SearchFailed = false;
     }
     else
-        line = textLine(curline);
+        line = text(curline);
     if (forward)
     {
         if (next)
@@ -377,9 +391,9 @@ void toMarkedText::incrementalSearch(bool forward, bool next)
                 return ;
             }
         }
-        for (curline++;curline < numLines();curline++)
+        for (curline++;curline < lines();curline++)
         {
-            int pos = textLine(curline).find(SearchString, 0, false);
+            int pos = text(curline).find(SearchString, 0, false);
             if (pos >= 0)
             {
                 searchFound(curline, pos);
@@ -402,7 +416,7 @@ void toMarkedText::incrementalSearch(bool forward, bool next)
         }
         for (curline--;curline >= 0;curline--)
         {
-            int pos = textLine(curline).findRev(SearchString, -1, false);
+            int pos = text(curline).findRev(SearchString, -1, false);
             if (pos >= 0)
             {
                 searchFound(curline, pos);
@@ -422,7 +436,7 @@ void toMarkedText::mousePressEvent(QMouseEvent *e)
         LastSearch = SearchString;
         toStatusMessage(QString::null);
     }
-    toMultiLineEdit::mousePressEvent(e);
+    QextScintilla::mousePressEvent(e);
 }
 
 void toMarkedText::incrementalSearch(bool forward)
@@ -446,19 +460,7 @@ void toMarkedText::incrementalSearch(bool forward)
 
 void toMarkedText::keyPressEvent(QKeyEvent *e)
 {
-    if (e->state() == 0 && e->key() == Key_Insert)
-    {
-        setOverwriteMode(!isOverwriteMode());
-        e->accept();
-        return ;
-    }
-    else if (toCheckKeyEvent(e, QKeySequence(tr("Ctrl+A", "Edit|Select All"))))
-    {
-        selectAll();
-        e->accept();
-        return ;
-    }
-    else if (Search)
+    if (Search)
     {
         bool ok = false;
         if (e->state() == NoButton && e->key() == Key_Backspace)
@@ -498,7 +500,7 @@ void toMarkedText::keyPressEvent(QKeyEvent *e)
             toStatusMessage(QString::null);
         }
     }
-    toMultiLineEdit::keyPressEvent(e);
+    QextScintilla::keyPressEvent(e);
 }
 
 void toMarkedText::exportData(std::map<QCString, QString> &data, const QCString &prefix)
@@ -509,7 +511,7 @@ void toMarkedText::exportData(std::map<QCString, QString> &data, const QCString
     getCursorPosition (&curline, &curcol);
     data[prefix + ":Column"] = QString::number(curcol);
     data[prefix + ":Line"] = QString::number(curline);
-    if (edited())
+    if (isModified())
         data[prefix + ":Edited"] = "Yes";
 }
 
@@ -521,7 +523,7 @@ void toMarkedText::importData(std::map<QCString, QString> &data, const QCString
     Filename = data[prefix + ":Filename"];
     setCursorPosition(data[prefix + ":Line"].toInt(), data[prefix + ":Column"].toInt());
     if (data[prefix + ":Edited"].isEmpty())
-        setEdited(false);
+        setModified(false);
 }
 
 static int FindIndex(const QString &str, int line, int col)
@@ -540,16 +542,16 @@ static int FindIndex(const QString &str, int line, int col)
 void toMarkedText::findPosition(int index, int &line, int &col)
 {
     int pos = 0;
-    for (int i = 0;i < numLines();i++)
+    for (int i = 0;i < lines();i++)
     {
-        QString str = textLine(i);
+        QString str = text(i);
         if (str.length() + pos >= (unsigned int)index)
         {
             line = i;
             col = index - pos;
             return ;
         }
-        pos += str.length() + 1;
+        pos += str.length();
     }
     col = -1;
     line = -1;
@@ -562,7 +564,7 @@ bool toMarkedText::searchNext(toSearchReplace *search)
 
     int col;
     int line;
-    cursorPosition(&line, &col);
+    getCursorPosition(&line, &col);
     int pos = FindIndex(text, line, col);
 
     int endPos;
@@ -572,9 +574,8 @@ bool toMarkedText::searchNext(toSearchReplace *search)
         int endLine;
         findPosition(pos, line, col);
         findPosition(endPos, endLine, endCol);
-        setCursorPosition(line, col, false);
-        setCursorPosition(endLine, endCol, true);
-
+        setSelection(line, col, endLine, endCol);
+        ensureCursorVisible();
         return true;
     }
 
@@ -591,7 +592,123 @@ bool toMarkedText::searchCanReplace(bool all)
 {
     if (isReadOnly())
         return false;
-    if (all || hasMarkedText())
+    if (all || hasSelectedText())
         return true;
     return false;
 }
+
+void toMarkedText::insert(const QString &str, bool select)
+{
+    int lineFrom;
+    int indexFrom;
+    int lineTo;
+    int indexTo;
+    
+    QextScintilla::removeSelectedText();
+
+    if(select)
+        getCursorPosition(&lineFrom, &indexFrom);
+    
+    // insert() doesn't work as advertised.
+    // docs say: "The new current position if after the inserted text."
+
+    // I thought it would mean that the cursor would be at the end of
+    // the inserted text. Now I'm not really sure what the heck that
+    // means.
+
+    // That means the selection is broken for now.
+    QextScintilla::insert(str);
+    
+    // get new position and select if requested
+    if(select) {
+        getCursorPosition(&lineTo, &indexTo);
+        setSelection(lineFrom, indexFrom, lineTo, indexTo);
+    }
+}
+
+void toMarkedText::setTextChanged()
+{
+    redoEnabled(isRedoAvailable());
+    undoEnabled(isUndoAvailable());
+    if (hasSelectedText()) {
+        setEdit();
+    }
+}
+
+void toMarkedText::contextMenuEvent(QContextMenuEvent *e)
+{
+    QGuardedPtr<toMarkedText> that = this;
+    QGuardedPtr<QPopupMenu> popup = createPopupMenu( e->pos() );
+    if ( !popup )
+	return;
+    
+    e->accept();
+
+    // NOTE: this emit exist for compatibility with older 
+    //       version of TOra. It will have to be removed 
+    //       once the way around it will be figured out
+    emit displayMenu(popup);
+    
+    int r = popup->exec( e->globalPos() );
+    delete popup;
+    
+    if (!that)
+        return;
+
+    if ( r == id[ IdClear ] )
+	    clear();
+    else if ( r == id[ IdSelectAll ] )
+	    editSelectAll();
+    else if ( r == id[ IdUndo ] )
+	    undo();
+    else if ( r == id[ IdRedo ] )
+	    redo();
+    else if ( r == id[ IdCut ] )
+	    cut();
+    else if ( r == id[ IdCopy ] )
+	    copy();
+    else if ( r == id[ IdPaste ] )
+	    paste();
+}
+
+/**
+ * This function is called to create a right mouse button popup menu
+ * at the specified position. If you want to create a custom popup menu, 
+ * reimplement this function and return the created popup menu. Ownership 
+ * of the popup menu is transferred to the caller.
+ */
+QPopupMenu *toMarkedText::createPopupMenu(const QPoint& pos)
+{
+    Q_UNUSED( pos )
+
+    // clear ID array
+    for (int i=0; i<IdSize; i++)
+        id[i] = 0;
+
+    // create menu
+    QPopupMenu *popup = new QPopupMenu( this, "qt_edit_menu" );
+    if ( !isReadOnly() ) {
+        id[ IdUndo ] = popup->insertItem( tr( "&Undo" ) + ACCEL_KEY( Z ) );
+        id[ IdRedo ] = popup->insertItem( tr( "&Redo" ) + ACCEL_KEY( Y ) );
+        popup->insertSeparator();
+        id[ IdCut ] = popup->insertItem( tr( "Cu&t" ) + ACCEL_KEY( X ) );
+        id[ IdCopy ] = popup->insertItem( tr( "&Copy" ) + ACCEL_KEY( C ) );
+    	id[ IdPaste ] = popup->insertItem( tr( "&Paste" ) + ACCEL_KEY( V ) );
+    	id[ IdClear ] = popup->insertItem( tr( "Clear" ) );
+	    popup->insertSeparator();
+    }
+#if defined(Q_WS_X11)
+    id[ IdSelectAll ] = popup->insertItem( tr( "Select All" ) );
+#else
+    id[ IdSelectAll ] = popup->insertItem( tr( "Select All" ) + ACCEL_KEY( A ) );
+#endif
+    popup->setItemEnabled( id[ IdUndo ], !isReadOnly() && isUndoAvailable() );
+    popup->setItemEnabled( id[ IdRedo ], !isReadOnly() && isRedoAvailable() );
+    popup->setItemEnabled( id[ IdCut ], !isReadOnly() && hasSelectedText() );
+    popup->setItemEnabled( id[ IdCopy ], hasSelectedText() );
+    popup->setItemEnabled( id[ IdPaste ], !isReadOnly() && !QApplication::clipboard()->text(QClipboard::Clipboard).isEmpty() );
+    const bool isEmptyDocument = (lines() == 0);
+    popup->setItemEnabled( id[ IdClear ], !isReadOnly() && !isEmptyDocument );
+    popup->setItemEnabled( id[ IdSelectAll ], !isEmptyDocument );
+    return popup;
+}
