@@ -53,6 +53,7 @@
 #include "totool.h"
 
 #include <stdio.h>
+#include <iostream>
 
 #include <qcheckbox.h>
 #include <qfile.h>
@@ -138,7 +139,7 @@ static void ThrowException(const otl_exception &exc)
             QString sql = QString::fromUtf8((const char *)exc.stm_text);
             if (exc.code >= 0)
             {
-                QString t = QString::fromUtf8((const char *)exc.stm_text, exc.code);
+                QString t = QString::fromUtf8((const char *)exc.stm_text, exc.error_offset);
                 ret.setOffset(t.length());
                 sql.insert(t.length(), QString::fromLatin1("<ERROR>"));
             }
@@ -184,7 +185,7 @@ class oracleSub : public toConnectionSub
         }
         virtual void throwExtendedException(toConnection &conn, const otl_exception &exc)
         {
-            if (conn.version() < "8.0" && exc.code == 0)
+            if (conn.version() < "0800" && exc.code == 0)
             {
                 // Serious OCI voodoo to get the Parse error location on Oracle7 servers
 
@@ -810,8 +811,20 @@ class oracleConnection : public toConnection::connectionImpl
                         int pos;
                         int len;
                         pos = verre.match(ver, 0, &len);
-                        if (pos >= 0)
-                            return ver.mid(pos, len).latin1();
+                        if (pos >= 0) {
+                            QCString verstr = ver.mid(pos, len).latin1();
+                            QStringList vl = QStringList::split('.',verstr);
+                            QString ve;
+                            QString verrj;
+                            for ( QStringList::iterator vi = vl.begin();
+                                  vi != vl.end();
+                                  ++vi ) {
+                                ve = *vi;
+                                verrj += ve.rightJustify(2,'0');
+                            }
+                            return QCString::QCString(verrj);
+                            // return verstr;
+                        }
                     }
                 }
             }
@@ -846,16 +859,18 @@ class oracleConnection : public toConnection::connectionImpl
                 toQuery query(connection(), QString::fromUtf8(sql), params);
         }
 
-        //     todo
-        //     virtual void parse(toConnectionSub *sub,const QCString &sql)
-        //       {
-        //         oracleSub *conn=oracleConv(sub);
-        //         try {
-        //           otl_cursor::parse(*(conn->Connection), sql);
-        //         } catch (const otl_exception &exc) {
-        //           ThrowException(exc);
-        //         }
-        //       }
+             virtual void parse(toConnectionSub *sub,const QCString &sql)
+               {
+                 oracleSub *conn=oracleConv(sub);
+                 try{
+                     conn->Connection->reset_throw_count(); 
+                     conn->Connection->syntax_check(sql);
+
+                 } catch (const otl_exception &exc) {
+                   conn->Connection->throw_count++;
+                   ThrowException(exc);
+                 }
+               }
     };
 
     toOracleProvider(void)
