@@ -90,6 +90,7 @@
 #include <CoreServices/CoreServices.h>
 #endif // Q_OS_MACX
 
+
 #define CHUNK_SIZE 31
 
 // A little magic to get lrefresh to work and get a check on qApp
@@ -316,8 +317,11 @@ static std::list<QString> LastMessages;
 
 void toStatusMessage(const QString &str, bool save, bool log)
 {
-    if (!toThread::mainThread())
+#ifndef WIN32
+    if (!toThread::mainThread()){
         return ;
+    }
+#endif
     toMain *main = dynamic_cast<toMain *>(qApp->mainWidget());
     if (main)
     {
@@ -338,6 +342,7 @@ void toStatusMessage(const QString &str, bool save, bool log)
         QToolTip::add
             (main->statusBar(), str);
     }
+    
 }
 
 std::list<QString> toStatusMessages(void)
@@ -1068,7 +1073,9 @@ QString toSaveFilename(const QString &filename, const QString &filter, QWidget *
 
 void toSetEnv(const QCString &var, const QCString &val)
 {
-#ifndef TO_HAS_SETENV
+#if TO_HAS_SETENV && !defined(WIN32)
+    setenv(var, val, 1);
+#else
     // Has a memory leak, but just a minor one.
 
     char *env = new char[var.length() + val.length() + 2];
@@ -1076,19 +1083,15 @@ void toSetEnv(const QCString &var, const QCString &val)
     strcat(env, "=");
     strcat(env, val);
     putenv(env);
-#else
-
-    setenv(var, val, 1);
 #endif
 }
 
 void toUnSetEnv(const QCString &var)
 {
-#ifndef TO_HAS_SETENV
-    toSetEnv(var, "");
-#else
-
+#if TO_HAS_SETENV && !defined(WIN32)
     unsetenv(var);
+#else
+    toSetEnv(var, "");
 #endif
 }
 
